@@ -1,3 +1,5 @@
+import pytz
+import datetime
 import pandas as pd
 import seaborn as sns
 import matplotlib.pyplot as plt
@@ -89,6 +91,10 @@ def create_playlist(type: str, headers: dict, user_id: str, base_playlist_name:
         This function will change the user's library either making a new playlist or making an existing one empty
 
     Args:
+        headers (dict): Request headers
+        user_id (str): Spotify User id
+        base_playlist_name (str): name of the base playlist
+        additional_info (str, optional): name of the song, artist, or whatever additional information is needed. Defaults to None\n
         type (str): the type of the playlist being created ('song', 'short', 'medium'), meaning:\n
         --- 'song': a playlist related to a song\n
         --- 'short': a playlist related to the short term favorites for that given user\n
@@ -99,11 +105,6 @@ def create_playlist(type: str, headers: dict, user_id: str, base_playlist_name:
         --- 'artist-related': a playlist related to a specific artist songs\n
         --- 'artist': a playlist containing only a specific artist songs\n
 
-        headers (dict): Request headers
-        user_id (str): Spotify User id
-        base_playlist_name (str): name of the base playlist
-        additional_info (str, optional): name of the song, artist, or whatever additional information is needed. Defaults to None
-
     Raises:
         ValueError: The type argument musts be one of the valid options
 
@@ -133,6 +134,31 @@ def create_playlist(type: str, headers: dict, user_id: str, base_playlist_name:
     elif type == 'artist':
         playlist_name = f"This once was {additional_info!r}"
         description = f'''{additional_info}'{"" if additional_info[-1] == "s" else "s"} songs, within the playlist {base_playlist_name}'''
+
+    elif type == 'profile-recommendation':
+        criteria = additional_info[0] if additional_info[0] != 'mixed' else 'genres, tracks and artists'
+        playlist_name = f"Profile Recommendation"
+        description = f'''Profile-based recommendations based on favorite {criteria}'''
+
+        if additional_info[1]:
+            now = datetime.datetime.now(tz=pytz.timezone('UTC'))
+            playlist_name += f' ({criteria} - {now.strftime("%Y-%m-%d")})'
+            description += f' - {now.strftime("%Y-%m-%d")} snapshot'
+        else:
+            playlist_name += f' ({criteria})'
+
+    elif type == 'playlist-recommendation':
+        criteria = additional_info[0] if additional_info[0] != 'mixed' else 'genres, tracks and artists'
+        time_range = f'for the last {additional_info[2]}' if additional_info[2] != 'all_time' else 'for all_time'
+        playlist_name = f"Playlist Recommendation {time_range}"
+        description = f'''Playlist-based recommendations based on favorite {criteria}, within the playlist {base_playlist_name} {time_range}'''
+
+        if additional_info[1]:
+            now = datetime.datetime.now(tz=pytz.timezone('UTC'))
+            playlist_name += f' ({criteria} - {now.strftime("%Y-%m-%d")})'
+            description += f' - {now.strftime("%Y-%m-%d")} snapshot'
+        else:
+            playlist_name += f' ({criteria})'
     else:
         raise ValueError('type not valid')
 
