@@ -30,8 +30,7 @@ def get_total_song_count(playlist_id: str, headers: dict) -> int:
     Returns:
         int: The total number of songs in the playlist
     """
-    playlist_res = requests.get_request(
-        url=f'https://api.spotify.com/v1/playlists/{playlist_id}', headers=headers)
+    playlist_res = requests.get_request(url=f'https://api.spotify.com/v1/playlists/{playlist_id}', headers=headers)
 
     return playlist_res.json()["tracks"]["total"]
 
@@ -53,7 +52,7 @@ def add_items_to_list(item_list: 'list[str]', items: 'list[str]') -> 'list[str]'
     return item_list
 
 
-def song_data(song: dict) -> 'tuple[str, str, float, list[str], datetime.datetime]':
+def song_data(song: dict, added_at: bool = True) -> 'tuple[str, str, float, list[str], datetime.datetime]':
     """Function that gets additional information about the song, like its name, artists, id, popularity, date when it was added to the playlist, etc.
 
     Args:
@@ -61,14 +60,16 @@ def song_data(song: dict) -> 'tuple[str, str, float, list[str], datetime.datetim
 
     Returns:
         tuple[str, str, float, list[str], datetime.datetime]: A tuple containing the song's information
-    """"""
-    Function that gets additional information about the song
-    like its name, artists, id, popularity
-
-    # Parameters
-    - song: the song raw dictionary
     """
-    return song["track"]['id'], song["track"]['name'], song["track"]['popularity'], [artist["name"] for artist in song["track"]["artists"]], song['added_at']
+    try:
+        data = [song["track"]['id'], song["track"]['name'], song["track"]['popularity'], [artist["name"] for artist in song["track"]["artists"]]]
+    except KeyError:
+        data = [song['id'], song['name'], song['popularity'], [artist["name"] for artist in song["artists"]]]
+
+    if added_at:
+        data.append(song['added_at'])
+
+    return data
 
 
 def item_list_indexed(items: 'list[str]', all_items: 'list[str]') -> 'list[int]':
@@ -125,7 +126,7 @@ def playlist_exists(name: str, base_playlist_name: str, headers: dict, _update_c
 
     for playlist in playlists:
 
-        if playlist[1] == name and (' Term Most-listened Tracks' in name or f', within the playlist {base_playlist_name}' in playlist[2] or _update_created_playlists):
+        if playlist[1] == name and (' Term Most-listened Tracks' in name or f', within the playlist {base_playlist_name}' in playlist[2] or _update_created_playlists or playlist[1] == name and 'Recommendation (' in name):
             return playlist[0]
 
     return False
@@ -216,6 +217,21 @@ def value_dict_to_value_and_percentage_dict(dictionary: 'dict[str, int]') -> 'di
     return dictionary
 
 def print_base_caracteristics(*args):
+    """
+    Function that receives a list of values and print them
+
+    Args:
+        name (str): name of the song
+        artists (list[str]): song's artists
+        genres (list[str]): song's genres
+        popularity (int): song's popularity
+        danceability (float): song's danceability
+        energy (float): song's energy
+        instrumentalness (float): song's instrumentalness
+        tempo (float): song's tempo
+        valence (float): song's valence
+
+    """
     name, genres, artists, popularity, danceability, energy, instrumentalness, tempo, valence = args
 
     print(f'{name = }')
